@@ -118,9 +118,14 @@ class BaseXenForoForumAdapter(BaseSiteAdapter):
     ## returns (is_chapter_url,normalized_url)
     def _is_normalize_chapterurl(self,url):
         is_chapter_url = False
+        # logger.debug("start norm:%s"%url)
 
         ## moved from extract metadata to share with normalize_chapterurl.
         if not url.startswith('http'):
+            # getURLPrefix() has trailing / already.
+            # remove if url also has starting /
+            if url.startswith('/'):
+                url = url[1:]
             url = self.getURLPrefix()+url
 
         if ( url.startswith(self.getURLPrefix()) or
@@ -134,10 +139,16 @@ class BaseXenForoForumAdapter(BaseSiteAdapter):
             url = url.replace('http://','https://')
 
             # http://forums.spacebattles.com/showpost.php?p=4755532&postcount=9
-            url = re.sub(r'showpost\.php\?p=([0-9]+)(&postcount=[0-9]+)?',self.getPathPrefix()+r'posts/\1/',url)
+            if 'showpost' in url:
+                url = re.sub(r'/showpost\.php\?p=([0-9]+)(&postcount=[0-9]+)?',
+                             self.getPathPrefix()+r'posts/\1/',url)
 
             # http://forums.spacebattles.com/goto/post?id=15222406#post-15222406
-            url = re.sub(r'goto/post\?id=([0-9]+)(#post-[0-9]+)?',self.getPathPrefix()+r'posts/\1/',url)
+            if 'goto' in url:
+                # logger.debug("goto:%s"%url)
+                url = re.sub(r'/goto/post\?id=([0-9]+)(#post-[0-9]+)?',
+                             self.getPathPrefix()+r'posts/\1/',url)
+                # logger.debug("after:%s"%url)
 
             url = re.sub(r'(^[\'"]+|[\'"]+$)','',url) # strip leading or trailing '" from incorrect quoting.
             url = re.sub(r'like$','',url) # strip 'like' if incorrect 'like' link instead of proper post URL.
@@ -767,18 +778,19 @@ class BaseXenForoForumAdapter(BaseSiteAdapter):
         if self.getConfig('replace_failed_smilies_with_alt_text'):
             for img in soup.find_all('img',src=re.compile(r'(^data:image|(failedtoload|clear.png)$)')):
                 # logger.debug("replace_failed_smilies_with_alt_text img: %s"%img)
-                clses = unicode(img['class']) # stringify list.
-                if img.has_attr('alt') and ('mceSmilie' in clses or 'smilie--sprite' in clses):
-                    ## Change the img to a span containing the alt
-                    ## text, remove attrs.  This is a one-way change.
-                    img.name='span'
-                    img.string = img['alt'].replace('`','') # no idea why some have `
-                    # not valid attrs on span.
-                    del img['alt']
-                    if img.has_attr('src'):
-                        del img['src']
-                    if img.has_attr('longdesc'):
-                        del img['longdesc']
+                if img.has_attr('class'):
+                    clses = unicode(img['class']) # stringify list.
+                    if img.has_attr('alt') and ('mceSmilie' in clses or 'smilie--sprite' in clses):
+                        ## Change the img to a span containing the alt
+                        ## text, remove attrs.  This is a one-way change.
+                        img.name='span'
+                        img.string = img['alt'].replace('`','') # no idea why some have `
+                        # not valid attrs on span.
+                        del img['alt']
+                        if img.has_attr('src'):
+                            del img['src']
+                        if img.has_attr('longdesc'):
+                            del img['longdesc']
         return super(BaseXenForoForumAdapter, self)._do_utf8FromSoup(url,soup,fetch,allow_replace_br_with_p)
 
 # from https://daviseford.com/blog/2017/04/27/python-string-to-title-including-punctuation.html
