@@ -18,6 +18,7 @@
 from __future__ import absolute_import
 import re
 import codecs
+import random
 
 # py2 vs py3 transition
 from . import six
@@ -45,6 +46,7 @@ import pickle
 ## isn't found in plugin when only imported down below inside
 ## get_scraper()
 import cloudscraper
+from cloudscraper.exceptions import CloudflareException
 
 from . import exceptions
 
@@ -247,6 +249,7 @@ def get_valid_set_options():
                'description_in_chapter':(['literotica.com'],None,boollist),
 
                'inject_chapter_title':(['asianfanfics.com','storiesonline.net','finestories.com','scifistories.com'],None,boollist),
+               'append_datepublished_to_storyurl':(['storiesonline.net','finestories.com','scifistories.com'],None,boollist),
 
                'auto_sub':(['asianfanfics.com'],None,boollist),
 
@@ -467,6 +470,7 @@ def get_valid_keywords():
                  'conditionals_use_lists',
                  'description_in_chapter',
                  'inject_chapter_title',
+                 'append_datepublished_to_storyurl',
                  'auto_sub',
                  'titlepage_end',
                  'titlepage_entries',
@@ -1132,12 +1136,16 @@ class Configuration(ConfigParser):
 
         if self.getConfig('use_cloudscraper',False):
             logger.debug("Using cloudscraper for POST")
-            resp = self.get_scraper().post(url,
-                                           headers=dict(headers),
-                                           data=parameters)
-            logger.debug("response code:%s"%resp.status_code)
-            resp.raise_for_status() # raises HTTPError if error code.
-            data = resp.content
+            try:
+                resp = self.get_scraper().post(url,
+                                               headers=dict(headers),
+                                               data=parameters)
+                logger.debug("response code:%s"%resp.status_code)
+                resp.raise_for_status() # raises HTTPError if error code.
+                data = resp.content
+            except CloudflareException as e:
+                msg = unicode(e).replace(' in the opensource (free) version','...')
+                raise exceptions.FailedToDownload('cloudscraper reports: "%s"'%msg)
         else:
             req = Request(url,
                           data=ensure_binary(urlencode(parameters)),
@@ -1269,11 +1277,19 @@ class Configuration(ConfigParser):
 
     def do_sleep(self,extrasleep=None):
         if extrasleep:
+            logger.debug("extra sleep:%s"%extrasleep)
             time.sleep(float(extrasleep))
+        t = None
         if self.override_sleep:
-            time.sleep(float(self.override_sleep))
+            t = float(self.override_sleep)
         elif self.getConfig('slow_down_sleep_time'):
-            time.sleep(float(self.getConfig('slow_down_sleep_time')))
+            t = float(self.getConfig('slow_down_sleep_time'))
+        ## sleep randomly between 0.5 time and 1.5 time.
+        ## So 8 would be between 4 and 12.
+        if t:
+            rt = random.uniform(t*0.5, t*1.5)
+            logger.debug("random sleep(%0.2f-%0.2f):%0.2f"%(t*0.5, t*1.5,rt))
+            time.sleep(rt)
 
     # parameters is a dict()
     def _fetchUrlOpened(self, url,
@@ -1287,8 +1303,10 @@ class Configuration(ConfigParser):
             # only one try for file:s.
             sleeptimes = [0]
         else:
-            sleeptimes = [0, 0.5, 4, 9]
+            sleeptimes = [0, 2, 7, 12]
         for sleeptime in sleeptimes:
+            if sleeptime:
+                logger.debug("retry sleep:%s"%sleeptime)
             time.sleep(sleeptime)
             try:
                 (data,opened)=self._fetchUrlRawOpened(url,
@@ -1311,7 +1329,13 @@ class Configuration(ConfigParser):
             except Exception as e:
                 excpt=e
                 logger.debug("Caught an exception reading URL: %s sleeptime(%s) Exception %s."%(unicode(safe_url(url)),sleeptime,unicode(e)))
-                raise
+                if isinstance(e,CloudflareException):
+                    ## cloudscraper exception messages can appear to
+                    ## come from FFF and cause confusion.
+                    msg = unicode(e).replace(' in the opensource (free) version','...')
+                    raise exceptions.FailedToDownload('cloudscraper reports: "%s"'%msg)
+                else:
+                    raise
 
         logger.debug("Giving up on %s" %safe_url(url))
         logger.debug(excpt, exc_info=True)
